==> spring-cloud-config-server-4.2.1-sources.jar: org/springframework/cloud/config/server/environment/vault/SpringVaultTemplateBuilder.java <==
/*
 * Copyright 2018-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.config.server.environment.vault;

import java.util.List;

import org.springframework.cloud.config.server.environment.ConfigTokenProvider;
import org.springframework.cloud.config.server.environment.VaultEnvironmentProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.vault.core.VaultTemplate;

/**
 * @author Kaveh Shamsi
 */
public class SpringVaultTemplateBuilder {

	private final ConfigTokenProvider configTokenProvider;

	private final List<SpringVaultClientAuthenticationProvider> authProviders;

	private final ApplicationContext applicationContext;

	public SpringVaultTemplateBuilder(ConfigTokenProvider configTokenProvider,
			List<SpringVaultClientAuthenticationProvider> authProviders, ApplicationContext applicationContext) {

		this.configTokenProvider = configTokenProvider;
		this.authProviders = authProviders;
		this.applicationContext = applicationContext;
	}

	public VaultTemplate build(VaultEnvironmentProperties vaultProperties) {
		SpringVaultClientConfiguration clientConfiguration = new SpringVaultClientConfiguration(vaultProperties,
				configTokenProvider, authProviders);
		clientConfiguration.setApplicationContext(applicationContext);
		return clientConfiguration.vaultTemplate();
	}

}

==> spring-cloud-config-server-4.3.0-sources.jar: org/springframework/cloud/config/server/environment/vault/SpringVaultTemplateBuilder.java <==
/*
 * Copyright 2018-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.config.server.environment.vault;

import java.util.List;

import org.springframework.cloud.config.server.environment.ConfigTokenProvider;
import org.springframework.cloud.config.server.environment.VaultEnvironmentProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.util.StringUtils;
import org.springframework.vault.core.VaultTemplate;

/**
 * @author Kaveh Shamsi
 */
public class SpringVaultTemplateBuilder {

	private final ConfigTokenProvider configTokenProvider;

	private final List<SpringVaultClientAuthenticationProvider> authProviders;

	private final ApplicationContext applicationContext;

	public SpringVaultTemplateBuilder(ConfigTokenProvider configTokenProvider,
			List<SpringVaultClientAuthenticationProvider> authProviders, ApplicationContext applicationContext) {

		this.configTokenProvider = configTokenProvider;
		this.authProviders = authProviders;
		this.applicationContext = applicationContext;
	}

	public VaultTemplate build(VaultEnvironmentProperties vaultProperties) {
		ConfigTokenProvider tokenProvider = isStaticToken(vaultProperties) ? vaultProperties::getToken
				: configTokenProvider;

		SpringVaultClientConfiguration clientConfiguration = new SpringVaultClientConfiguration(vaultProperties,
				tokenProvider, authProviders);
		clientConfiguration.setApplicationContext(applicationContext);

		var vaultTemplate = clientConfiguration.vaultTemplate();
		vaultTemplate.setSessionManager(clientConfiguration.sessionManager());

		return vaultTemplate;
	}

	private boolean isStaticToken(VaultEnvironmentProperties vaultProperties) {
		return vaultProperties.getAuthentication() == null && StringUtils.hasText(vaultProperties.getToken());
	}

}
